@@ -4,13 +4,26 @@ QUEUEDIR="$HOME/.msmtpqueue"
 LOCKFILE="$QUEUEDIR/.lock"
 MAXWAIT=120
 
-OPTIONS=$@
+OPTIONS=$*
+
+# eat some options that would cause msmtp to return 0 without sendmail mail
+case "$OPTIONS" in 
+	*--help*)
+	echo "$0: send mails in $QUEUEDIR"
+	echo "Options are passed to msmtp"
+	exit 0
+	;;
+	*--version*)
+	echo "$0: unknown version"
+	exit 0
+	;;
+esac
 
 # wait for a lock that another instance has set
 WAIT=0
-while [ -e "$LOCKFILE" -a "$WAIT" -lt "$MAXWAIT" ]; do
+while [ -e "$LOCKFILE" ] && [ "$WAIT" -lt "$MAXWAIT" ]; do
 	sleep 1
-	WAIT="`expr "$WAIT" + 1`"
+	WAIT="$((WAIT + 1))"
 done
 if [ -e "$LOCKFILE" ]; then
 	echo "Cannot use $QUEUEDIR: waited $MAXWAIT seconds for"
@@ -24,7 +37,7 @@ fi
 cd "$QUEUEDIR" || exit 1
 
 # check for empty queuedir
-if [ "`echo *.mail`" = '*.mail' ]; then
+if [ "$(echo ./*.mail)" = './*.mail' ]; then
 	echo "No mails in $QUEUEDIR"
 	exit 0
 fi
@@ -34,14 +47,14 @@ touch "$LOCKFILE" || exit 1
 
 # process all mails
 for MAILFILE in *.mail; do
-	MSMTPFILE="`echo $MAILFILE | sed -e 's/mail/msmtp/'`"
-	echo "*** Sending $MAILFILE to `sed -e 's/^.*-- \(.*$\)/\1/' $MSMTPFILE` ..."
+	MSMTPFILE="$(echo $MAILFILE | sed -e 's/mail/msmtp/')"
+	echo "*** Sending $MAILFILE to $(sed -e 's/^.*-- \(.*$\)/\1/' $MSMTPFILE) ..."
 	if [ ! -f "$MSMTPFILE" ]; then
 		echo "No corresponding file $MSMTPFILE found"
 		echo "FAILURE"
 		continue
 	fi
-	msmtp $OPTIONS `cat "$MSMTPFILE"` < "$MAILFILE"
+	msmtp $OPTIONS $(cat "$MSMTPFILE") < "$MAILFILE"
 	if [ $? -eq 0 ]; then
 		rm "$MAILFILE" "$MSMTPFILE"
 		echo "$MAILFILE sent successfully"
